# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: straxrpc/straxrpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='straxrpc/straxrpc.proto',
  package='straxrpc',
  syntax='proto3',
  serialized_pb=_b('\n\x17straxrpc/straxrpc.proto\x12\x08straxrpc\"0\n\x06\x43onfig\x12\x13\n\x0bpax_raw_dir\x18\x01 \x01(\t\x12\x11\n\tinput_dir\x18\x02 \x01(\t\" \n\rSearchPattern\x12\x0f\n\x07pattern\x18\x01 \x01(\t\")\n\tTableInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\t\"=\n\nColumnInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdata_name\x18\x02 \x01(\t\x12\x0e\n\x06plugin\x18\x03 \x01(\t\".\n\nPluginInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nclass_name\x18\x02 \x01(\t\"?\n\x0cTableRequest\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\t\x12\x10\n\x08max_size\x18\x03 \x01(\r\"R\n\nArrayChunk\x12\r\n\x05nrows\x18\x01 \x01(\r\x12\x12\n\nserializer\x18\x02 \x01(\t\x12\x13\n\x0b\x63ompression\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"Q\n\tDataframe\x12\r\n\x05nrows\x18\x01 \x01(\r\x12\x12\n\nserializer\x18\x02 \x01(\t\x12\x13\n\x0b\x63ompression\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x32\xc7\x02\n\x08StraxRPC\x12@\n\x0bSearchField\x12\x17.straxrpc.SearchPattern\x1a\x14.straxrpc.ColumnInfo\"\x00\x30\x01\x12I\n\x14SearchDataframeNames\x12\x17.straxrpc.SearchPattern\x1a\x14.straxrpc.PluginInfo\"\x00\x30\x01\x12\x36\n\x08\x44\x61taInfo\x12\x13.straxrpc.TableInfo\x1a\x13.straxrpc.Dataframe\"\x00\x12<\n\x08GetArray\x12\x16.straxrpc.TableRequest\x1a\x14.straxrpc.ArrayChunk\"\x00\x30\x01\x12\x38\n\nShowConfig\x12\x13.straxrpc.TableInfo\x1a\x13.straxrpc.Dataframe\"\x00\x62\x06proto3')
)




_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='straxrpc.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pax_raw_dir', full_name='straxrpc.Config.pax_raw_dir', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_dir', full_name='straxrpc.Config.input_dir', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37,
  serialized_end=85,
)


_SEARCHPATTERN = _descriptor.Descriptor(
  name='SearchPattern',
  full_name='straxrpc.SearchPattern',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pattern', full_name='straxrpc.SearchPattern.pattern', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=119,
)


_TABLEINFO = _descriptor.Descriptor(
  name='TableInfo',
  full_name='straxrpc.TableInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='straxrpc.TableInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_id', full_name='straxrpc.TableInfo.run_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=162,
)


_COLUMNINFO = _descriptor.Descriptor(
  name='ColumnInfo',
  full_name='straxrpc.ColumnInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='straxrpc.ColumnInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_name', full_name='straxrpc.ColumnInfo.data_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='straxrpc.ColumnInfo.plugin', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=225,
)


_PLUGININFO = _descriptor.Descriptor(
  name='PluginInfo',
  full_name='straxrpc.PluginInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='straxrpc.PluginInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='straxrpc.PluginInfo.class_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=273,
)


_TABLEREQUEST = _descriptor.Descriptor(
  name='TableRequest',
  full_name='straxrpc.TableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='straxrpc.TableRequest.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_id', full_name='straxrpc.TableRequest.run_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_size', full_name='straxrpc.TableRequest.max_size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=338,
)


_ARRAYCHUNK = _descriptor.Descriptor(
  name='ArrayChunk',
  full_name='straxrpc.ArrayChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nrows', full_name='straxrpc.ArrayChunk.nrows', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serializer', full_name='straxrpc.ArrayChunk.serializer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compression', full_name='straxrpc.ArrayChunk.compression', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='straxrpc.ArrayChunk.data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=422,
)


_DATAFRAME = _descriptor.Descriptor(
  name='Dataframe',
  full_name='straxrpc.Dataframe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nrows', full_name='straxrpc.Dataframe.nrows', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serializer', full_name='straxrpc.Dataframe.serializer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compression', full_name='straxrpc.Dataframe.compression', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='straxrpc.Dataframe.data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=505,
)

DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.message_types_by_name['SearchPattern'] = _SEARCHPATTERN
DESCRIPTOR.message_types_by_name['TableInfo'] = _TABLEINFO
DESCRIPTOR.message_types_by_name['ColumnInfo'] = _COLUMNINFO
DESCRIPTOR.message_types_by_name['PluginInfo'] = _PLUGININFO
DESCRIPTOR.message_types_by_name['TableRequest'] = _TABLEREQUEST
DESCRIPTOR.message_types_by_name['ArrayChunk'] = _ARRAYCHUNK
DESCRIPTOR.message_types_by_name['Dataframe'] = _DATAFRAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), dict(
  DESCRIPTOR = _CONFIG,
  __module__ = 'straxrpc.straxrpc_pb2'
  # @@protoc_insertion_point(class_scope:straxrpc.Config)
  ))
_sym_db.RegisterMessage(Config)

SearchPattern = _reflection.GeneratedProtocolMessageType('SearchPattern', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHPATTERN,
  __module__ = 'straxrpc.straxrpc_pb2'
  # @@protoc_insertion_point(class_scope:straxrpc.SearchPattern)
  ))
_sym_db.RegisterMessage(SearchPattern)

TableInfo = _reflection.GeneratedProtocolMessageType('TableInfo', (_message.Message,), dict(
  DESCRIPTOR = _TABLEINFO,
  __module__ = 'straxrpc.straxrpc_pb2'
  # @@protoc_insertion_point(class_scope:straxrpc.TableInfo)
  ))
_sym_db.RegisterMessage(TableInfo)

ColumnInfo = _reflection.GeneratedProtocolMessageType('ColumnInfo', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNINFO,
  __module__ = 'straxrpc.straxrpc_pb2'
  # @@protoc_insertion_point(class_scope:straxrpc.ColumnInfo)
  ))
_sym_db.RegisterMessage(ColumnInfo)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), dict(
  DESCRIPTOR = _PLUGININFO,
  __module__ = 'straxrpc.straxrpc_pb2'
  # @@protoc_insertion_point(class_scope:straxrpc.PluginInfo)
  ))
_sym_db.RegisterMessage(PluginInfo)

TableRequest = _reflection.GeneratedProtocolMessageType('TableRequest', (_message.Message,), dict(
  DESCRIPTOR = _TABLEREQUEST,
  __module__ = 'straxrpc.straxrpc_pb2'
  # @@protoc_insertion_point(class_scope:straxrpc.TableRequest)
  ))
_sym_db.RegisterMessage(TableRequest)

ArrayChunk = _reflection.GeneratedProtocolMessageType('ArrayChunk', (_message.Message,), dict(
  DESCRIPTOR = _ARRAYCHUNK,
  __module__ = 'straxrpc.straxrpc_pb2'
  # @@protoc_insertion_point(class_scope:straxrpc.ArrayChunk)
  ))
_sym_db.RegisterMessage(ArrayChunk)

Dataframe = _reflection.GeneratedProtocolMessageType('Dataframe', (_message.Message,), dict(
  DESCRIPTOR = _DATAFRAME,
  __module__ = 'straxrpc.straxrpc_pb2'
  # @@protoc_insertion_point(class_scope:straxrpc.Dataframe)
  ))
_sym_db.RegisterMessage(Dataframe)



_STRAXRPC = _descriptor.ServiceDescriptor(
  name='StraxRPC',
  full_name='straxrpc.StraxRPC',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=508,
  serialized_end=835,
  methods=[
  _descriptor.MethodDescriptor(
    name='SearchField',
    full_name='straxrpc.StraxRPC.SearchField',
    index=0,
    containing_service=None,
    input_type=_SEARCHPATTERN,
    output_type=_COLUMNINFO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SearchDataframeNames',
    full_name='straxrpc.StraxRPC.SearchDataframeNames',
    index=1,
    containing_service=None,
    input_type=_SEARCHPATTERN,
    output_type=_PLUGININFO,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DataInfo',
    full_name='straxrpc.StraxRPC.DataInfo',
    index=2,
    containing_service=None,
    input_type=_TABLEINFO,
    output_type=_DATAFRAME,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetArray',
    full_name='straxrpc.StraxRPC.GetArray',
    index=3,
    containing_service=None,
    input_type=_TABLEREQUEST,
    output_type=_ARRAYCHUNK,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ShowConfig',
    full_name='straxrpc.StraxRPC.ShowConfig',
    index=4,
    containing_service=None,
    input_type=_TABLEINFO,
    output_type=_DATAFRAME,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STRAXRPC)

DESCRIPTOR.services_by_name['StraxRPC'] = _STRAXRPC

# @@protoc_insertion_point(module_scope)



from __future__ import print_function
import grpc
from . import straxrpc_pb2
from . import straxrpc_pb2_grpc
import pandas as pd
import numpy as np
from collections import defaultdict
import pickle

class StraxClient:

    def __init__(self, addr="localhost:50051"):
        self.addr = addr 

    def search_field(self, pattern):
         with grpc.insecure_channel(self.addr) as channel:
            stub = straxrpc_pb2_grpc.StraxRPCStub(channel)
            sp = straxrpc_pb2.SearchPattern(pattern=pattern)
            rs = stub.SearchField(sp)
            results = [f"{r.name} is part of {r.data_name} (provided by {r.plugin})" for r in rs]
            # print(results)
            return results

    def data_info(self, dataname):
        with grpc.insecure_channel(self.addr) as channel:
            stub = straxrpc_pb2_grpc.StraxRPCStub(channel)
            ti = straxrpc_pb2.TableInfo(name=dataname)
            r = stub.DataInfo(ti)
            df = pickle.loads(r.data)
            return df

    def get_array_iter(self, run_id, dframes):
        if isinstance(dframes, str):
            names = [dframes]
        else:
            names = dframes
        with grpc.insecure_channel(self.addr) as channel:
            stub = straxrpc_pb2_grpc.StraxRPCStub(channel)
            ti = straxrpc_pb2.TableRequest(names=names, run_id=run_id)
            for r in stub.GetArray(ti):
                arr = pickle.loads(r.data)
                yield arr

    def get_array(self, run_id, dframe):
        records = np.hstack([arr for arr in self.get_array_iter(run_id, dframe)])
        return records

    def get_df_iter(self, run_id, dframe):
        for records in self.get_array_iter(run_id, dframe):
            df = pd.DataFrame.from_records(records)
            yield df

    def get_df(self, run_id, dframe):
        records = self.get_array(run_id, dframe)
        df = pd.DataFrame.from_records(records)
        return df

    def show_config(self, name):
        with grpc.insecure_channel(self.addr) as channel:
            stub = straxrpc_pb2_grpc.StraxRPCStub(channel)
            ti = straxrpc_pb2.TableInfo(name=name)
            r = stub.ShowConfig(ti)
            df = pickle.loads(r.data)
            return df

    def search_dataframe_names(self, pattern):
        with grpc.insecure_channel(self.addr) as channel:
            stub = straxrpc_pb2_grpc.StraxRPCStub(channel)
            sp = straxrpc_pb2.SearchPattern(pattern=pattern,)
            rs = stub.SearchDataframeNames(sp)
            names = [x.name for x in rs]
            # print(names)
            return names


            # data = {}
            # for col in stub.ShowConfig(ti):
            #     vs = getattr(col, col.info.dtype).values
            #     data[col.info.name] = pd.Series(index=col.index, data=vs)
            # df = pd.DataFrame(data)
            # return df


def run():
    client = StraxClient()
    print("---------------------- Search for s1* ----------------------")
    res = client.search_field( "s1*")
    print("\n".join(res))
    print("\n-------------- Data Info for event_basics --------------\n")
    df = client.data_info( 'event_basics')
    print(df)
    print("\n--------- Get event_basics df for 180423_1021 ---------\n")
    df = client.get_df( '180423_1021', 'event_basics')
    print(df)
    print("\n--------- Get event_basics array for 180423_1021 ---------\n")
    arr = client.get_array( '180423_1021', 'event_basics')
    print(arr.dtype.names)
    print(arr)

if __name__ == '__main__':
    run()
